<?php

declare(strict_types=1);

namespace Drupal\carbon_impact_evaluator\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for Carbon impact evaluator routes.
 */
final class CarbonImpactEvaluatorController extends ControllerBase {

  /**
   * Builds the response to Ajax request with visit status.
   */

  public function handleAjaxVisitStatus() {
    $valor = json_decode(\Drupal::request()->get('valor'), true);
    $nid = $valor['nid'];
    $visitStatus = $valor['visit_status'];  
    $table = \Drupal::database();
    $visit_table = $table->select('co2_info', 'co2_info')
                      ->condition('node_id', $nid)
                      ->fields('co2_info',['first_visit', 'return_visit'])
                      ->execute()
                      ->fetchAll();
    $field_visit_status = $visit_table[0]->$visitStatus;
    $status_count = $field_visit_status + 1;
    $updated_table = $table->update('co2_info')
          ->condition('node_id', $nid)
          ->fields([
            $visitStatus => $status_count
          ])
          ->execute();
    $new_table = $table->select('co2_info', 'co2_info')
                      ->condition('node_id', $nid)
                      ->fields('co2_info',['first_visit', 'return_visit', 'total_number_visits'])
                      ->execute()
                      ->fetchAll();
    return new JsonResponse(['status' => 'sucesso', 'valor' => $new_table[0]]);
  }

  /**
   * Builds the response to Ajax request with CO2 calculations.
   */
  public function handleAjaxPerVisit() {
    $valor = json_decode(\Drupal::request()->get('valor'), true);
    $nid = $valor['nid'];
    $calculations = $valor['calculations'];
    $calc_identifier = $valor['identifier'];
    $table = \Drupal::database();
    $visit_table = $table->select('co2_info', 'co2_info')
                      ->condition('node_id', $nid)
                      ->fields('co2_info',['per_visit','per_byte'])
                      ->execute()
                      ->fetchAll();
    $field_calculations = $visit_table[0]->$calc_identifier;
    $updated_table = $table->update('co2_info')
          ->condition('node_id', $nid)
          ->fields([
            $calc_identifier => $calculations
          ])
          ->execute();
    return new JsonResponse(['status' => 'sucesso', 'valor' => $calculations]);
  }

  /**
   * This function will display visit data for each page in a table format.
   */
  public function displayTable() {
    $table_query = \Drupal::database()
                      ->select('co2_info', 'co2_info')
                      ->fields('co2_info',[
                        'node_id',
                        'node_title',
                        'node_url',
                        'total_number_visits',
                        'first_visit',
                        'return_visit', 
                        'per_byte',
                        'per_visit',
                        'date'
                      ])
                      ->execute()
                      ->fetchAll();
    $table_rows = array();
    foreach($table_query as $k => $table_content) {
      foreach($table_query as $k => $table_content) {
        $table_rows[] = [
          $table_content->node_id,
          $table_content->node_title,
          $table_content->node_url,
          $table_content->total_number_visits,
          $table_content->first_visit,
          $table_content->return_visit,
          $table_content->per_byte,
          $table_content->per_visit,
          $table_content->date,
        ];
      }
    }
    $table_header = [
      'ID',
      'Title',
      'URL',
      'Total',
      'First visits',
      'Return visits', 
      'CO2/Per Byte',
      'CO2/Per Visit',
      'Date',
    ];
    $table = array(
      '#type' => 'table',
      '#header' => $table_header,
      '#rows' => $table_rows,
      '#attributes' => [
        'class' => ['carbon-table']
      ], 
      '#attached' => [
        
      ]
    );
    return $table;
  }

}
